// src/index.ts
import {
  send
} from "vite";
import posthtml from "posthtml";
import fs from "fs/promises";
import path from "path";
import { transformAsync as babelTransformAsync } from "@babel/core";

// package.json
var name = "vite-plugin-legacy-dev";

// src/index.ts
var COREJS_PATH = "/@legacydev/corejs3";
var FETCH_PATH = "/@legacydev/fetch";
var SYSTEMJS_PATH = "/@legacydev/systemjs";
var WEBCOMPONENTS_PATH = "/@legacydev/webcomponents";
var helpers = /* @__PURE__ */ new Map([
  [COREJS_PATH, "core-js-bundle/index.js"],
  [FETCH_PATH, "whatwg-fetch/dist/fetch.umd.js"],
  [WEBCOMPONENTS_PATH, "@webcomponents/webcomponentsjs/webcomponents-bundle.js"],
  [SYSTEMJS_PATH, "systemjs/dist/system.js"]
]);
var transformESMToSystemjs = (code, filename) => babelTransformAsync(code, {
  presets: [
    [
      "@babel/preset-env",
      {
        modules: "systemjs",
        useBuiltIns: false
      }
    ]
  ],
  filename
});
var vitePluginLegacyDev = () => {
  let server;
  let config;
  const vitePluginLegacyDevPostTransform = {
    name: "vite-plugin-legacy-dev-post-transform",
    async transform(code, id) {
      if (new URLSearchParams(id.split("?")[1] || "").has("direct"))
        return;
      const transformResult = await transformESMToSystemjs(code, id);
      if (transformResult && transformResult.code) {
        return {
          code: transformResult.code
        };
      }
    }
  };
  return {
    name: "vite-plugin-legacy-dev",
    apply: "serve",
    enforce: "post",
    configResolved(_config) {
      config = _config;
      config.plugins.push(vitePluginLegacyDevPostTransform);
    },
    configureServer(_server) {
      server = _server;
      server.middlewares.use(async (req, res, next) => {
        if (req.url && helpers.has(req.url)) {
          const content = await fs.readFile(
            path.resolve(config.root, `node_modules/${name}/node_modules`, helpers.get(req.url)),
            "utf-8"
          );
          return send(req, res, content.toString(), "js", {});
        }
        next();
      });
    },
    transformIndexHtml: {
      enforce: "post",
      async transform(html) {
        const result = await posthtml([
          (tree) => {
            tree.match({ tag: "script" }, (node) => {
              const attrs = node.attrs;
              if (attrs && attrs.type === "module") {
                attrs.type = "systemjs-module";
              }
              return node;
            });
          }
        ]).process(html);
        return {
          html: result.html,
          tags: Array.from(helpers.keys()).map((src) => ({
            tag: "script",
            injectTo: "head-prepend",
            attrs: {
              src
            }
          }))
        };
      }
    }
  };
};
var src_default = vitePluginLegacyDev;
export {
  src_default as default
};
